# <span class="badge package-variant-dataquery"></span> tempo

## Objects

 * <span class="badge object-type-enum"></span> [SearchStreamingState](./object-SearchStreamingState.md)
 * <span class="badge object-type-enum"></span> [SearchTableType](./object-SearchTableType.md)
 * <span class="badge object-type-class"></span> [TempoQuery](./object-TempoQuery.md)
 * <span class="badge object-type-enum"></span> [TempoQueryType](./object-TempoQueryType.md)
 * <span class="badge object-type-class"></span> [TraceqlFilter](./object-TraceqlFilter.md)
 * <span class="badge object-type-enum"></span> [TraceqlSearchScope](./object-TraceqlSearchScope.md)
## Builders

 * <span class="badge builder"></span> [TempoQuery](./builder-TempoQuery.md)
 * <span class="badge builder"></span> [TraceqlFilter](./builder-TraceqlFilter.md)
## Functions

### <span class="badge function"></span> variant_config

variant_config returns the configuration related to tempo data queries.

This configuration describes how to unmarshal it, convert it to code, …

```python
def variant_config() -> variants.DataqueryConfig
```

